[jboss-cvs] JBossAS SVN: r87884 - branches/Branch_5_x/system/src/main/org/jboss/system/server/profileservice.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Mon Apr 27 13:54:16 EDT 2009


Author: scott.stark at jboss.org
Date: 2009-04-27 13:54:16 -0400 (Mon, 27 Apr 2009)
New Revision: 87884

Modified:
   branches/Branch_5_x/system/src/main/org/jboss/system/server/profileservice/ProfileServiceBootstrap.java
Log:
JBAS-6618, only overwrite MO name if its equal to the attachment name

Modified: branches/Branch_5_x/system/src/main/org/jboss/system/server/profileservice/ProfileServiceBootstrap.java
===================================================================
--- branches/Branch_5_x/system/src/main/org/jboss/system/server/profileservice/ProfileServiceBootstrap.java	2009-04-27 17:43:13 UTC (rev 87883)
+++ branches/Branch_5_x/system/src/main/org/jboss/system/server/profileservice/ProfileServiceBootstrap.java	2009-04-27 17:54:16 UTC (rev 87884)
@@ -460,13 +460,12 @@
 
                Map<String, Annotation> moAnns = bmdMO.getAnnotations();
                ManagementObject mo = (ManagementObject) moAnns.get(ManagementObject.class.getName());
                // Reset the name to the bean name
                if(bmdMO instanceof MutableManagedObject)
                {
                   MutableManagedObject mmo = (MutableManagedObject) bmdMO;
-                  if(mo != null && mo.name().length() > 0 && mo.name().equals(ManagementConstants.GENERATED) == false)
-                     mmo.setName(mo.name());
-                  else
+                  // Reset the name to the bean name if its the attachment name
+                  if(mmo.getName().equals(mmo.getAttachmentName()))
                      mmo.setName(bmd.getName());
                   mmo.setParent(kdMO);
                   // Add an alias property
@@ -460,13 +460,12 @@
                Map<String, Annotation> moAnns = bmdMO.getAnnotations();
                ManagementObject mo = (ManagementObject) moAnns.get(ManagementObject.class.getName());
-               // Reset the name to the bean name
+               // Reset the name to the bean name rather than the attachment name
                if(bmdMO instanceof MutableManagedObject)
                {




More information about the jboss-cvs-commits mailing list